# ABConfig

[![Build Status](https://travis-ci.org/kudato/abconfig.svg?branch=master)](https://travis-ci.org/kudato/abconfig) [![Coverage Status](https://coveralls.io/repos/github/kudato/abconfig/badge.svg?branch=master)](https://coveralls.io/github/kudato/abconfig?branch=master)

The configuration should be simple, this project aims to give you all the power while maintaining ease of use.


## Features

- Json or Yaml files and environment variables are supported as source;

- Correct data types (even for environment variables);

- Create configurations in django models style;

- The result object is a regular dictionary;


## Read the docs

**Documentation**: http://abconfig.readthedocs.io/

> Also strongly recommend that you read ["The twelve-factor app" for config](https://12factor.net/ru/config) before starting.
